import android.view.MotionEvent;
import ketai.ui.*;

KetaiGesture gesture;
ArrayList<Ripple> ripples = new ArrayList<Ripple>();
ArrayList<Splash> splashes = new ArrayList<Splash>();
color rippleColor;
int colorDefault = 200; // blue
int colorSelection = colorDefault;
int colorChangeRate = 3;
int maxRipples = 10;
int mousePressedTimer = 0;
float mousePressedDelay = frameRate / 3.0;
boolean clearLists = false;

void setup() {
  background(0);
  size(displayWidth, displayHeight);
  orientation(LANDSCAPE);
  colorMode(HSB, 360, 100, 100, 100);
  rippleColor = color(colorDefault, 100, 100);
  gesture = new KetaiGesture(this);
}

// the draw function uses tap gesture input to draw 
// ripples and stars on the screen.
// The ripples are drawn wherever the user taps
// The stars are drawn wherever the user flicks
// The star size depends on flick velocity (faster = bigger)
// The pinch gesture will clear all drawings.

void draw() {
  background(0,0,0,100);
  
  if (clearLists) {
    ripples.clear();
    splashes.clear();
    clearLists = false; 
  }
  
  if (mousePressed) {
    mousePressedTimer++;
    
    if (mousePressedTimer >= mousePressedDelay)
    {
      colorSelection += colorChangeRate;
      if (colorSelection > 360)
        colorSelection = 0;
        
      fill(colorSelection, 100, 100);
      ellipse(mouseX, mouseY, 250, 250);
    }
  } else {
    mousePressedTimer = 0;
  }
  
  int ripplesDrawn = 0;
  //if we have ripples lets reverse through them 
  //  so we can delete dead ones and draw live ones
  if (ripples.size() > 0)
    for (int i = ripples.size ()-1; i >= 0; i--)
    {
      Ripple selectedRipple = ripples.get(i);
      
      if (selectedRipple.isDead() || ripplesDrawn >= maxRipples) {
        ripples.remove(selectedRipple);
      } else {
        selectedRipple.draw();
        ripplesDrawn++;
      }
    }
    
    for (int i = splashes.size() - 1; i >= 0; i--)
    {
       Splash selectedSplash = splashes.get(i);
       if (selectedSplash.isDead())
         splashes.remove(selectedSplash);
       else
         selectedSplash.draw();
    }
}

//whenever the user taps the screen, use the X and Y location to create new ripple objects that can be drawn
void onTap(float x, float y)
{
  ripples.add(new Ripple(x, y, colorSelection));
}

void onFlick(float x, float y, float px, float py, float v)
{
  splashes.add(new Splash(x, y, px, py, v, colorSelection));
}

void onPinch(float x, float y, float r)
{
  clearLists = true;
  mousePressed = false;
}

public boolean surfaceTouchEvent(MotionEvent event) {

  //call to keep mouseX, mouseY, etc updated
  super.surfaceTouchEvent(event);

  //forward event to class for processing
  return gesture.surfaceTouchEvent(event);
}

